@@ -918,9 +918,10 @@ Delay according to `listen-queue-delay-time-range', which see."
          :columns
          (list (list :name "▶" :primary 'descend
                      :getter (lambda (queue _table)
-                               (when-let ((player listen-player))
-                                 (if (eq queue (map-elt (listen-player-etc player) :queue))
-                                     "▶" " "))))
+                               (if-let ((player listen-player)
+                                        ((eq queue (alist-get :queue (listen-player-etc player)))))
+                                   "▶"
+                                 " ")))
                (list :name "Name" :primary 'ascend
                      :getter (lambda (queue _table)
                                (listen-queue-name queue)))
@@ -929,7 +930,7 @@ Delay according to `listen-queue-delay-time-range', which see."
                                (length (listen-queue-tracks queue))))
                (list :name "Duration" :align 'right
                      :getter (lambda (queue _table)
-                               (when-let ((duration (map-elt (listen-queue-etc queue) :duration)))
+                               (when-let ((duration (alist-get :duration (listen-queue-etc queue))))
                                  (listen-format-seconds duration)))))
          :objects-function (lambda ()
                              listen-queues)
